# Other DEM software
This page lists other tools that are written in Python for carrying out DEM inversions.
They all use different methods to ``demcmc``.

- [demregpy](https://github.com/alasdairwilson/demregpy) (Python)
